# frozen_string_literal: true

module Gitlab
  module BackgroundMigration
    class MigrateSharedVulnerabilityScanners < BatchedMigrationJob
      feature_category :database

      def perform; end
    end
  end
end

# rubocop: disable Layout/LineLength
Gitlab::BackgroundMigration::MigrateSharedVulnerabilityScanners.prepend_mod_with("Gitlab::BackgroundMigration::MigrateSharedVulnerabilityScanners")
# rubocop: enable Layout/LineLength
